## Swanki

[![CI](https://github.com/Mjvolk3/Swanki/actions/workflows/ci.yml/badge.svg)](https://github.com/Mjvolk3/Swanki/actions/workflows/ci.yml) [![codecov](https://codecov.io/gh/Mjvolk3/Swanki/graph/badge.svg)](https://codecov.io/gh/Mjvolk3/Swanki) ![Ruff](https://img.shields.io/badge/linter-ruff-orange) ![mypy strict](https://img.shields.io/badge/typing-mypy%20strict-blue) ![Python 3.13](https://img.shields.io/badge/python-3.13-blue) ![License: MIT](https://img.shields.io/badge/license-MIT-green)

![Swanki Pipeline](docs/figure_1.png)

[Paper (Word)](notes/assets/publish/export/paper_0.docx)